@@ -29,10 +29,6 @@
 #ifndef _DDD_BoxExtend_h
 #define _DDD_BoxExtend_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 // A `BoxExtend' denotes the extensibility of a box - that is, how
 // much the box extends to fill up available space.  An extensibility
 // of 0 means that the box will not extend at all.  The bigger the
@@ -62,37 +58,37 @@ public:
     {}
 
     // Horizontal concatenation
-    BoxExtend operator & (const BoxExtend& e) 
+    BoxExtend operator & (const BoxExtend& e) const
     {
-	if (isValid() && e.isValid())
-	    return BoxExtend(point[X] + e.point[X],
-			     min(point[Y],e.point[Y]));
-	else
-	    return BoxExtend();
+        return
+	  (isValid() && e.isValid())
+	  ? BoxExtend(point[X] + e.point[X],
+		      min(point[Y],e.point[Y]))
+	  : BoxExtend();
     }
 
     // Vertical concatenation
-    BoxExtend operator | (const BoxExtend& e) 
+    BoxExtend operator | (const BoxExtend& e) const
     {
-	if (isValid() && e.isValid())
-	    return BoxExtend(min(point[X], e.point[X]),
-			     point[Y] + e.point[Y]);
-	else
-	    return BoxExtend();
+        return
+	  (isValid() && e.isValid())
+	  ? BoxExtend(min(point[X], e.point[X]),
+		      point[Y] + e.point[Y])
+	  : BoxExtend();
     }
 
     // Stacked concatenation
-    BoxExtend operator ^ (const BoxExtend& e) 
+    BoxExtend operator ^ (const BoxExtend& e) const
     {
-	if (isValid() && e.isValid())
-	    return BoxExtend(max(point[X], e.point[X]),
-			     max(point[Y], e.point[Y]));
-	else
-	    return BoxExtend();
+	return
+	  (isValid() && e.isValid())
+	  ? BoxExtend(max(point[X], e.point[X]),
+		      max(point[Y], e.point[Y]))
+	  : BoxExtend();
     }
 
     // Assignment versions
-    void operator &= (const BoxExtend& e) 
+    void operator &= (const BoxExtend& e)
     {
 	if (isValid() && e.isValid())
 	{
