@@ -29,11 +29,6 @@
 #ifndef _DDD_TestNode_h
 #define _DDD_TestNode_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 // A TestNode implements an if-then-else-fi construct.
 
 // A TestNode contains a List of length 3.  Upon evaluation, the wird
@@ -62,6 +57,9 @@ private:
     ListNode *_true() const  { return (ListNode *)(_test()->tail()); }
     ListNode *_false() const { return (ListNode *)(_true()->tail()); }
 
+private:
+    TestNode& operator = (const TestNode&);
+
 protected:
     void dump(std::ostream& s) const;
     void _dumpTree(std::ostream& s) const;
