@@ -29,10 +29,6 @@
 #ifndef _DDD_TrueBox_h
 #define _DDD_TrueBox_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "bool.h"
 #include "Box.h"
 #include "PrimitiveB.h"
@@ -41,14 +37,14 @@
 class TrueBox: public SquareBox {
 public:
     DECLARE_TYPE_INFO
-    TrueBox(): SquareBox(true) {}
+    TrueBox(): SquareBox(1) {}
 };
 
 // False
 class FalseBox: public SquareBox {
 public:
     DECLARE_TYPE_INFO
-    FalseBox(): SquareBox(false) {}
+    FalseBox(): SquareBox(0) {}
 };
 
 // Zero
