@@ -29,10 +29,6 @@
 #ifndef _DDD_ddd_h
 #define _DDD_ddd_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 #include <fstream>
 
