@@ -29,14 +29,13 @@
 #ifndef _DDD_environ_h
 #define _DDD_environ_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 
 // Put NAME=VALUE into the environment
-extern void put_environment(const string& name, const string& value);
+extern void put_environment(const char *name, const char *value);
+inline void put_environment(const string& name, const string& value){
+  put_environment(name.chars(), value.chars());
+}
 
 // Return NAME1=VALUE1 NAME2=VALUE2 for each name defined by PUT_ENVIRONMENT
 extern string set_environment_command();
