@@ -29,16 +29,17 @@
 #ifndef _DDD_index_h
 #define _DDD_index_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 
 // Return index of R in S, starting with POS; PREFIX is the constant
 // prefix of R.
 extern int index(const string& s, const regex& r, 
-		 const string& prefix, int pos = 0);
+		 const char *prefix, int pos = 0);
+
+inline int index(const string& s, const regex& r, 
+		 const string& prefix, int pos = 0){
+  return index(s, r, prefix.chars(), pos);
+}
 
 #endif // _DDD_index_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
